@@ -26,7 +26,7 @@ class Handler(HandlerBase):
             description="Generate report showing only passing tests.",
             formatter_class=HelpFormatter)
 
-        parser.add_argument("input", metavar="input", type=argtype.file("r", bufsize=1, encoding="utf-8"),
+        parser.add_argument("input", metavar="input", type=argtype.logfile("r", bufsize=1, encoding="utf-8"),
                 nargs="?", help="input log, default: stdin", default="-")
         parser.add_argument("output", metavar="output", type=argtype.file("w", bufsize=1, encoding="utf-8"),
                 nargs="?", help='output file, default: stdout', default="-")
@@ -34,4 +34,4 @@ class Handler(HandlerBase):
         parser.set_defaults(func=cls())
 
     def handle(self, args):
-        PassingReportLogPipeline(args.input, args.output).run()
\ No newline at end of file
+        PassingReportLogPipeline(args.input, args.output).run()
