@@ -14,13 +14,14 @@
 # limitations under the License.
 import io
 import sys
+import csv
 import argparse
 
 from argparse import ArgumentTypeError
 from collections import namedtuple
 from testflows._core.exceptions import exception
-
 from testflows._core.compress import CompressedFile
+from testflows._core.funcs import repeat as Repeat
 
 KeyValue = namedtuple("KeyValue", "key value")
 
@@ -119,3 +120,34 @@ def key_value(s, sep='='):
         raise ArgumentTypeError(f"invalid format of key{sep}value")
     key, value= s.split(sep, 1)
     return KeyValue(key.strip(), value.strip())
+
+def count(value):
+    try:
+        value = int(value)
+        assert value >= 0
+    except:
+        raise ArgumentTypeError(f"{value} is not a positive number")
+    return value
+
+def repeat(value):
+    try:
+        fields = list(csv.reader([value],"unix"))[-1]
+        option = Repeat(*fields)
+    except Exception as e:
+        raise ArgumentTypeError(f"'{value}' is invalid")
+    return option
+
+def tags_filter(value):
+    try:
+        type, cvstags = value.split(":", 1)
+        assert type in ["test", "suite", "module", "feature", "scenario"]
+        tags = list(csv.reader([cvstags],"unix"))[-1]
+        if type == "scenario":
+            type = "test"
+        elif type == "feature":
+            type = suite
+        option = {type: set(tags)}
+    except Exception as e:
+        raise ArgumentTypeError(f"'{value}' is invalid")
+    return option
+
