@@ -13,16 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import os
+import sys
 import inspect
 import importlib
 import threading
 
 from .exceptions import ResultException
-from .message import Message, dumps
+from .message import Message, dumps, namedtuple_with_defaults
 from .objects import OK, Fail, Error, Skip, Null
 from .objects import XOK, XFail, XError, XNull
-from .objects import Value, Metric, Ticket
+from .objects import Value, Metric, Ticket, ExamplesTable, Table, Node
 from .testtype import TestSubType
+from .filters import the
 
 #: thread local values
 _current_test = {}
@@ -60,13 +62,40 @@ def previous(value=None, thread=None):
         _current_test[thread.ident]["previous"] = value
     return _current_test[thread.ident].get("previous")  
 
-def load(module, test=None):
-    """Load test from module path.
-
-    :param module: module path
-    :param test: test class or method to load (optional)
+def current_dir(frame=None):
+    """Return directory of the current source file.
     """
-    module = importlib.import_module(module)
+    if frame is None:
+        frame = inspect.currentframe().f_back
+    return os.path.dirname(os.path.abspath(frame.f_globals["__file__"]))
+
+def current_module(frame=None):
+    """Return reference to the current module.
+    """
+    if frame is None:
+        frame = inspect.currentframe().f_back
+    return sys.modules[frame.f_globals["__name__"]]
+
+def load_module(name, package=None):
+    """Load module by name.
+    """
+    return importlib.import_module(module, package=package)
+
+def load(name, test=None, package=None, frame=None):
+    """Load test by name from module.
+
+    :param name: module name or module
+    :param test: test class or method name to load (optional)
+    :param package: package if module name is relative (optional)
+    """
+    if name is None or name == ".":
+        if frame is None:
+            frame = inspect.currentframe().f_back
+        module = sys.modules[frame.f_globals["__name__"]]
+    elif inspect.ismodule(name):
+        module = name
+    else:
+        module = importlib.import_module(name, package=package)
     if test:
         test = getattr(module, test, None)
     if test is None:
@@ -159,56 +188,56 @@ def exception(exc_type=None, exc_value=None, exc_traceback=None, test=None):
 def ok(message=None, test=None):
     if test is None:
         test = current()
-    test.result = OK(test.name, message)
-    raise ResultException(test.result)
+    test.result = OK(test=test.name, message=message)
+    raise test.result
 
 def fail(message=None, test=None):
     if test is None:
         test = current()
-    test.result = Fail(test.name, message)
-    raise ResultException(test.result)
+    test.result = Fail(test=test.name, message=message)
+    raise test.result
 
 def skip(message=None, test=None):
     if test is None:
         test = current()
-    test.result = Skip(test.name, message)
-    raise ResultException(test.result)
+    test.result = Skip(test=test.name, message=message)
+    raise test.result
 
-def error(message=None, test=None):
+def err(message=None, test=None):
     if test is None:
         test = current()
-    test.result = Error(test.name, message)
-    raise ResultException(test.result)
+    test.result = Error(test=test.name, message=message)
+    raise test.result
 
-def null(test=None):
+def null(message=None, test=None):
     if test is None:
         test = current()
-    test.result = Null(test.name)
-    raise ResultException(test.result)
+    test.result = Null(test=test.name, message=message)
+    raise test.result
 
-def xok(message=None, test=None):
+def xok(message=None, reason=None, test=None):
     if test is None:
         test = current()
-    test.result = XOK(test.name, message)
-    raise ResultException(test.result)
+    test.result = XOK(test=test.name, message=message, reason=reason)
+    raise test.result
 
-def xfail(message=None, test=None):
+def xfail(message=None, reason=None, test=None):
     if test is None:
         test = current()
-    test.result = XFail(test.name, message)
-    raise ResultException(test.result)
+    test.result = XFail(test=test.name, message=message, reason=reason)
+    raise test.result
 
-def xerror(message=None, test=None):
+def xerr(message=None, reason=None, test=None):
     if test is None:
         test = current()
-    test.result = XError(test.name, message)
-    raise ResultException(test.result)
+    test.result = XError(test=test.name, message=message, reason=reason)
+    raise test.result
 
-def xnull(test=None):
+def xnull(message=None, reason=None, test=None):
     if test is None:
         test = current()
-    test.result = XNull(test.name)
-    raise ResultException(test.result)
+    test.result = XNull(test=test.name, message=message, reason=reason)
+    raise test.result
 
 def pause(test=None):
     if test is None:
@@ -216,16 +245,97 @@ def pause(test=None):
     test.io.output.input("Paused, enter any key to continue...")
     input()
 
-def enter_context(cm, test=None):
-    if test is None:
-        test = current()
-    if not test.caller_test or test.caller_test.subtype != TestSubType.Background:
-        raise TypeError("not inside a background test")
-    return test.caller_test.stack.enter_context(cm)
-
 def getsattr(obj, name, *default):
     """Get attribute or set it to the default value.
     """
     value = getattr(obj, name, *default)
     setattr(obj, name, value)
     return value
+
+class xfails(dict):
+    """xfails container.
+
+    xfails = {
+        "pattern": [("result", "reason")],
+        ...
+        }
+    """
+    def add(self, pattern, *results):
+        """Add an entry to the xfails.
+
+        :param pattern: test name pattern to match
+        :param *results: one or more results to cross out
+            where each result is a two-tuple of (result, reason)
+        """
+        self[pattern] = results
+        return self
+
+class xflags(dict):
+    """xflags container.
+
+    xflags = {
+        "filter": (set_flags, clear_flags),
+        ...
+    }
+    """
+    def add(self, pattern, set_flags=0, clear_flags=0):
+        """Add an entry to the xflags.
+
+        :param pattern: test name pattern to match
+        :param set_flags: flags to set
+        :param clear_flags: flags to clear, default: None
+        """
+        self[pattern] = [Flags(set_flags), Flags(clear_flags)]
+        return self
+
+class tags(set):
+    """tags container."""
+    def __init__(self, tag, *tags):
+        if type(tag) in (tuple, set):
+            tag = list(tag)
+        else:
+            tag = [tag]
+        return super(tags, self).__init__(tags + tag)
+
+class examples(ExamplesTable):
+    """examples container."""
+    pass
+
+class table(Table):
+    """table container."""
+    pass
+
+class repeat(namedtuple_with_defaults("repeat", "pattern number until", defaults=("fail",))):
+    """repeat container."""
+    def __new__(cls, *args):
+        args = list(args)
+        l = len(args)
+        if l > 0:
+            if not isinstance(args[0], the):
+                args[0] = the(args[0])
+        if l > 1:
+            args[1] = int(args[1])
+            assert args[1] > 0
+        if l > 2:
+            assert args[2] in ("fail", "pass", "complete")
+        return super(repeat, cls).__new__(cls, *args)
+
+def maps(test, nexts=None, ins=None, outs=None, map=[]):
+    """Map a test.
+
+    :param test: test
+    :param nexts: next steps
+    :param ins: input steps
+    :param outs: output steps
+    """
+    if getattr(test.func, "node", None) is not None:
+        raise ValueError("test has already been mapped")
+
+    nexts = [Node.attributes(step).uid for step in nexts or []]
+    ins = [Node.attributes(step).uid for step in ins or []]
+    outs = [Node.attributes(step).uid for step in outs or []]
+
+    test.func.node = Node(*Node.attributes(test), nexts, ins, outs)
+
+    map.append(test.func.node)
+    return map
