@@ -165,7 +165,9 @@ def format_test(msg, keyword):
     test_type = get_type(msg)
     test_subtype = get_subtype(msg)
 
-    if test_type == TestType.Module:
+    if test_subtype == TestSubType.Example:
+        keyword += "Example"
+    elif test_type == TestType.Module:
         keyword += "Module"
     elif test_type == TestType.Suite:
         if test_subtype == TestSubType.Feature:
@@ -189,13 +191,13 @@ def format_test(msg, keyword):
             keyword += and_keyword(msg, parent, "But", TestSubType.But)
         elif test_subtype == TestSubType.Finally:
             keyword += and_keyword(msg, parent, "Finally", TestSubType.Finally)
+        elif test_subtype == TestSubType.Background:
+            keyword += and_keyword(msg, parent, "Background", TestSubType.Background)
         else:
             keyword += "Step"
     else:
         if test_subtype == TestSubType.Scenario:
             keyword += "Scenario"
-        elif test_subtype == TestSubType.Background:
-            keyword += "Background"
         else:
             keyword += "Test"
 
